@@ -2,7 +2,7 @@
 ;; Copyright (C) 1999 Lookup Development Team <lookup@ring.gr.jp>
 
 ;; Author: Keisuke Nishida <kei@psn.net>
-;; Version: $Id: lookup-entry.el,v 1.4 1999/06/03 02:14:40 knishida Exp $
+;; Version: $Id: lookup-entry.el,v 1.5 2000/01/05 07:37:22 tsuchiya Exp $
 
 ;; This file is part of Lookup.
 
@@ -35,6 +35,8 @@
 (make-variable-buffer-local 'lookup-entry-line-pattern)
 (make-variable-buffer-local 'lookup-entry-line-number)
 
+(defvar lookup-entry-insert-format "%-19s ")
+
 ;;;;;;;;;;;;;;;;;;;;
 ;: Construct Buffer
 ;;;;;;;;;;;;;;;;;;;;
@@ -102,7 +104,7 @@
 	(prefix (lookup-entry-prefix entry))
 	(heading (lookup-entry-heading entry))
 	start end)
-    (insert (format "%-19s " (lookup-dictionary-title dictionary)))
+    (insert (format lookup-entry-insert-format (lookup-dictionary-title dictionary)))
     ;; property $B$d(B extent $B$r<!$N9T$K$^$?$,$J$$$h$&$K@h$K(B newline $B$7$F$*$/!#(B
     (newline)
     (backward-char)
@@ -154,6 +156,7 @@
   (define-key lookup-entry-mode-map " " 'lookup-entry-next-page)
   (define-key lookup-entry-mode-map "\C-?" 'lookup-entry-previous-page)
   (define-key lookup-entry-mode-map [delete] 'lookup-entry-previous-page)
+  (define-key lookup-entry-mode-map [backspace] 'lookup-entry-previous-page)
   (define-key lookup-entry-mode-map "\C-m" 'lookup-entry-scroll-up-content)
   (define-key lookup-entry-mode-map "<" 'lookup-entry-beginning-of-content)
   (define-key lookup-entry-mode-map ">" 'lookup-entry-end-of-content)
@@ -244,6 +247,8 @@
   (setq truncate-lines t)
   (setq buffer-read-only t)
   (use-local-map lookup-entry-mode-map)
+  (if (and (featurep 'xemacs) (featurep 'scrollbar))
+      (set-specifier scrollbar-height (cons (current-buffer) 0)))
   (run-hooks 'lookup-entry-mode-hook))
 
 (defun lookup-entry-overview-mode (&optional arg)
