@@ -2,7 +2,7 @@
 ;; Copyright (C) 1999 Lookup Development Team <lookup@ring.gr.jp>
 
 ;; Author: Keisuke Nishida <kei@psn.net>
-;; Version: $Id: lookup-utils.el,v 1.5 1999/10/20 06:45:32 knishida Exp $
+;; Version: $Id: lookup-utils.el,v 1.6 2000/03/07 17:07:06 knishida Exp $
 
 ;; This file is part of Lookup.
 
@@ -300,9 +300,11 @@ window $B$K@_Dj$7$?>uBV$G(B BODY $B$r<B9T$9$k!#(B"
 (defun lookup-current-word-general ()
   ;; `lookup-current-word' $B$NFbIt4X?t!#(B
   ;; syntax $B$,(B "w" $B$G$"$kJ8;z$NO"$J$j$rC18l$H$7$F@Z$j=P$9!#(B
-  (buffer-substring-no-properties
-   (progn (skip-syntax-backward "w") (point))
-   (progn (skip-syntax-forward "w") (point))))
+  (if (fboundp 'thing-at-point)
+      (thing-at-point 'word)
+    (buffer-substring-no-properties
+     (progn (skip-syntax-backward "w") (point))
+     (progn (skip-syntax-forward "w") (point)))))
 
 (defun lookup-current-word-ascii ()
   ;; `lookup-current-word' $B$NFbIt4X?t!#(B
